==> ra-sdk-1.0.5-20200922.061634-2-sources.jar: com/xdja/ra/bean/TemplateInfo.java <==
package com.xdja.ra.bean;

import java.util.List;

/**
 * @author: ggp
 * @Date: 2019/10/22 18:08
 * @Description:
 */
public class TemplateInfo {
    /**
     * 必须 模板定义的密钥长度
     */
    private Integer keyLength;
    /**
     * 必须 模板定义的签名算法
     */
    private String signAlg;
    /**
     * 必须 模板定义的证书有效期
     */
    private Integer tempCertValidity;
    /**
     * 必须 模板编号
     */
    private String tempNo;
    /**
     * 非必须 模板中的扩展项内容
     */
    private List<Extension> extensions;

    /**
     * 自定义证书DN
     */
    private String baseDn;
    /**
     * 证书审核策略 1人工审核 2 页面审核
     */
    private Integer checkStrategy;

    public String getBaseDn() {
        return baseDn;
    }

    public void setBaseDn(String baseDn) {
        this.baseDn = baseDn;
    }

    public Integer getKeyLength() {
        return keyLength;
    }

    public void setKeyLength(Integer keyLength) {
        this.keyLength = keyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public Integer getTempCertValidity() {
        return tempCertValidity;
    }

    public void setTempCertValidity(Integer tempCertValidity) {
        this.tempCertValidity = tempCertValidity;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public List<Extension> getExtensions() {
        return extensions;
    }

    public void setExtensions(List<Extension> extensions) {
        this.extensions = extensions;
    }

    public Integer getCheckStrategy() {
        return checkStrategy;
    }

    public void setCheckStrategy(Integer checkStrategy) {
        this.checkStrategy = checkStrategy;
    }

    @Override
    public String toString() {
        return "TemplateInfo{" +
                "keyLength=" + keyLength +
                ", signAlg='" + signAlg + '\'' +
                ", tempCertValidity=" + tempCertValidity +
                ", tempNo='" + tempNo + '\'' +
                ", extensions=" + extensions +
                ", baseDn='" + baseDn + '\'' +
                ", checkStrategy=" + checkStrategy +
                '}';
    }
}

==> ra-sdk-2.0.0-20210115.083039-19-sources.jar: com/xdja/ra/bean/TemplateInfo.java <==
package com.xdja.ra.bean;

import java.util.List;

/**
 * @author: ggp
 * @Date: 2019/10/22 18:08
 * @Description:
 */
public class TemplateInfo {
    /**
     * 必须 模板定义的密钥长度
     */
    private Integer keyLength;
    /**
     * 必须 模板定义的签名算法
     */
    private String signAlg;
    /**
     * 必须 模板定义的证书有效期
     */
    private Integer tempCertValidity;
    /**
     * 必须 模板编号
     */
    private String tempNo;
    /**
     * 非必须 模板中的扩展项内容
     */
    private List<Extension> extensions;

    /**
     * 自定义证书DN
     */
    private String baseDn;
    /**
     * 证书审核策略 1人工审核 2 页面审核
     */
    private Integer checkStrategy;
    /**
     * 所属用户CA
     */
    private String userCA;

    public String getUserCA() {
        return userCA;
    }

    public void setUserCA(String userCA) {
        this.userCA = userCA;
    }

    public String getBaseDn() {
        return baseDn;
    }

    public void setBaseDn(String baseDn) {
        this.baseDn = baseDn;
    }

    public Integer getKeyLength() {
        return keyLength;
    }

    public void setKeyLength(Integer keyLength) {
        this.keyLength = keyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public Integer getTempCertValidity() {
        return tempCertValidity;
    }

    public void setTempCertValidity(Integer tempCertValidity) {
        this.tempCertValidity = tempCertValidity;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public List<Extension> getExtensions() {
        return extensions;
    }

    public void setExtensions(List<Extension> extensions) {
        this.extensions = extensions;
    }

    public Integer getCheckStrategy() {
        return checkStrategy;
    }

    public void setCheckStrategy(Integer checkStrategy) {
        this.checkStrategy = checkStrategy;
    }

    @Override
    public String toString() {
        return "TemplateInfo{" +
                "keyLength=" + keyLength +
                ", signAlg='" + signAlg + '\'' +
                ", tempCertValidity=" + tempCertValidity +
                ", tempNo='" + tempNo + '\'' +
                ", extensions=" + extensions +
                ", baseDn='" + baseDn + '\'' +
                ", checkStrategy=" + checkStrategy +
                ", userCA='" + userCA + '\'' +
                '}';
    }
}
